@@ -3,7 +3,7 @@
 +--------------------------------------------------------------------+
 | CiviCRM version 4.7                                                |
 +--------------------------------------------------------------------+
-| Copyright CiviCRM LLC (c) 2004-2015                                |
+| Copyright CiviCRM LLC (c) 2004-2016                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
@@ -28,11 +28,11 @@
 /**
  *
  * @package CRM
- * @copyright CiviCRM LLC (c) 2004-2015
+ * @copyright CiviCRM LLC (c) 2004-2016
  * $Id$
  *
  */
-class CRM_Core_I18n_SchemaStructure_3_4_0 {
+class CRM_Core_I18n_SchemaStructure_4_1_0 {
   /**
    * @return array
    */
@@ -40,8 +40,11 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
     static $result = NULL;
     if (!$result) {
       $result = array(
+        'civicrm_location_type' => array(
+          'display_name' => "varchar(64)",
+        ),
         'civicrm_option_group' => array(
-          'label' => "varchar(255)",
+          'title' => "varchar(255)",
           'description' => "varchar(255)",
         ),
         'civicrm_contact_type' => array(
@@ -57,10 +60,6 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'description' => "text",
           'options' => "text",
         ),
-        'civicrm_membership_type' => array(
-          'name' => "varchar(128)",
-          'description' => "varchar(255)",
-        ),
         'civicrm_membership_status' => array(
           'label' => "varchar(128)",
         ),
@@ -115,21 +114,11 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'honor_block_title' => "varchar(255)",
           'honor_block_text' => "text",
         ),
-        'civicrm_membership_block' => array(
-          'new_title' => "varchar(255)",
-          'new_text' => "text",
-          'renewal_title' => "varchar(255)",
-          'renewal_text' => "text",
-        ),
         'civicrm_price_field' => array(
           'label' => "varchar(255)",
           'help_pre' => "text",
           'help_post' => "text",
         ),
-        'civicrm_price_field_value' => array(
-          'label' => "varchar(255)",
-          'description' => "text",
-        ),
         'civicrm_uf_group' => array(
           'title' => "varchar(64)",
           'help_pre' => "text",
@@ -140,6 +129,23 @@ class CRM_Core_I18n_SchemaStructure_3_4_0 {
           'help_pre' => "text",
           'label' => "varchar(255)",
         ),
+        'civicrm_membership_type' => array(
+          'name' => "varchar(128)",
+          'description' => "varchar(255)",
+        ),
+        'civicrm_membership_block' => array(
+          'new_title' => "varchar(255)",
+          'new_text' => "text",
+          'renewal_title' => "varchar(255)",
+          'renewal_text' => "text",
+        ),
+        'civicrm_price_field_value' => array(
+          'label' => "varchar(255)",
+          'description' => "text",
+        ),
+        'civicrm_pcp_block' => array(
+          'link_text' => "varchar(255)",
+        ),
         'civicrm_event' => array(
           'title' => "varchar(255)",
           'summary' => "text",
