@@ -3,7 +3,7 @@
   +--------------------------------------------------------------------+
   | CiviCRM version 4.7                                                |
   +--------------------------------------------------------------------+
-  | Copyright CiviCRM LLC (c) 2004-2015                                |
+  | Copyright CiviCRM LLC (c) 2004-2016                                |
   +--------------------------------------------------------------------+
   | This file is a part of CiviCRM.                                    |
   |                                                                    |
@@ -28,7 +28,7 @@
 /**
  *
  * @package CRM
- * @copyright CiviCRM LLC (c) 2004-2015
+ * @copyright CiviCRM LLC (c) 2004-2016
  * $Id$
  *
  */
@@ -1056,6 +1056,29 @@ WHERE  id = %1";
     if ($className == 'CRM_Contribute_Form_Contribution_Main') {
       $form->_quickConfig = $quickConfig;
     }
+
+    // Mark which field should have the auto-renew checkbox, if any. CRM-18305
+    if (is_array($form->_membershipTypeValues)) {
+      $autoRenewMembershipTypes = array();
+      foreach ($form->_membershipTypeValues as $membershiptTypeValue) {
+        if ($membershiptTypeValue['auto_renew']) {
+          $autoRenewMembershipTypes[] = $membershiptTypeValue['id'];
+        }
+      }
+      foreach ($form->_priceSet['fields'] as &$field) {
+        if (array_key_exists('options', $field) && is_array($field['options'])) {
+          foreach ($field['options'] as $option) {
+            if ($option['membership_type_id']) {
+              if (in_array($option['membership_type_id'], $autoRenewMembershipTypes)) {
+                $form->_priceSet['auto_renew_membership_field'] = $field['id'];
+                // Only one field can offer auto_renew memberships, so break here.
+                break;
+              }
+            }
+          }
+        }
+      }
+    }
     $form->assign('priceSet', $form->_priceSet);
 
     $component = 'contribution';
