@@ -3,7 +3,7 @@
  +--------------------------------------------------------------------+
  | CiviCRM version 4.7                                                |
  +--------------------------------------------------------------------+
- | Copyright CiviCRM LLC (c) 2004-2015                                |
+ | Copyright CiviCRM LLC (c) 2004-2016                                |
  +--------------------------------------------------------------------+
  | This file is a part of CiviCRM.                                    |
  |                                                                    |
@@ -28,7 +28,7 @@
 /**
  *
  * @package CRM
- * @copyright CiviCRM LLC (c) 2004-2015
+ * @copyright CiviCRM LLC (c) 2004-2016
  */
 
 /**
@@ -677,6 +677,21 @@ class CRM_Utils_System_Joomla extends CRM_Utils_System_Base {
     return $destination;
   }
 
+  /**
+   * Determine the location of the CMS root.
+   *
+   * @return string|NULL
+   *   local file system path to CMS root, or NULL if it cannot be determined
+   */
+  public function cmsRootPath() {
+    list($url, $siteName, $siteRoot) = $this->getDefaultSiteSettings();
+    $includePath = "$siteRoot/libraries/cms/version";
+    if (file_exists("$includePath/version.php")) {
+      return $siteRoot;
+    }
+    return NULL;
+  }
+
   /**
    * @inheritDoc
    */
