@@ -1944,7 +1944,7 @@ class HTML_QuickForm extends HTML_Common
                     // …or should be skipped…
                     or CRM_Core_HTMLInputCoder::isSkippedField($fldName)
                     //CRM-17962 - do not encode if element is a wysiwyg editor
-                    or $this->_elements[$key]->_attributes['class'] = 'crm-form-wysiwyg'
+                    or CRM_Utils_Array::value('class', $this->_elements[$key]->_attributes) == 'crm-form-wysiwyg'
                 ) {
                     // …don’t filter, otherwise filter (else clause below)
                 } else {
